..
    Copyright 2021 IRT Saint Exupéry, https://www.irt-saintexupery.com

    This work is licensed under the Creative Commons Attribution-ShareAlike 4.0
    International License. To view a copy of this license, visit
    http://creativecommons.org/licenses/by-sa/4.0/ or send a letter to Creative
    Commons, PO Box 1866, Mountain View, CA 94042, USA.


GEMSEO stands for
"Generic Engine for Multi-disciplinary Scenarios, Exploration and Optimization",
it features:

- Automatic creation and execution of MDO processes based on MDO formulations
- Integration of numerical techniques in MDO processes: multidisciplinary
  coupling, optimization, design of experiments, visualization, surrogate
  models, machine learning, uncertainty, ...
- Various ways of interfacing software and models: Python, Matlab, Excel,
  scilab, executables, ...
- A Python library, standalone and easy to embed in simulation platforms
- Built on NumPy, SciPy and matplotlib
- Open-source LGPL-3.0 license

Documentation
-------------

The full documentation of GEMSEO, including installation and tutorials,
can be found at https://gemseo.readthedocs.io.

Bugs/Questions
--------------

Please use the gitlab issue tracker at
https://gitlab.com/gemseo/dev/gemseo/-/issues
to submit bugs or questions.

License
-------

The GEMSEO source code is distributed under the GNU LGPL v3.0 license.
A copy of it can be found in the LICENSE.txt file.
The GNU LGPL v3.0 license is an exception to the GNU GPL v3.0 license.
A copy of the GNU GPL v3.0 license can be found in the LICENSES folder.

The GEMSEO examples are distributed under the BSD 0-Clause, a permissive
license that allows to copy paste the code of examples without preserving the
copyright mentions.

The GEMSEO documentation is distributed under the CC BY-SA 4.0 license.

The GEMSEO product depends on other software which have various licenses.
The list of dependencies with their licenses is given in the CREDITS.rst file.

Contributors
------------

- Francois Gallard
- Damien Guenot
- Vincent Gachelin
- Charlie Vanaret
- Remi Lafage
- Pierre-Jean Barjhoux
- Benoit Pauwels
- Matthias De Lozzo
- Jean-Christophe Giret
- Syver Doving Agdestein
- Antoine Dechaume
- Anne Gazaix
- Nicolas Roussouly
- Gilberto Ruiz Jimenez
